pub struct MockReportsApi {
ReportsApi_expectations: MockReportsApi_ReportsApi,
}Fields
ReportsApi_expectations: MockReportsApi_ReportsApiImplementations
Sourceimpl MockReportsApi
impl MockReportsApi
Sourcepub fn checkpoint(&mut self)
pub fn checkpoint(&mut self)
Validate that all current expectations for all methods have been satisfied, and discard them.
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new mock object with no expectations.
This method will not be generated if the real struct
already has a new method. However, it will be
generated if the struct implements a trait with a new
method. The trait’s new method can still be called
like <MockX as TraitY>::new
Sourceimpl MockReportsApi
impl MockReportsApi
Sourcepub fn expect_add_password_health_report_application(
&mut self,
) -> &mut Expectation
pub fn expect_add_password_health_report_application( &mut self, ) -> &mut Expectation
Create an Expectation for mocking the add_password_health_report_application method
Sourcepub fn expect_add_password_health_report_applications(
&mut self,
) -> &mut Expectation
pub fn expect_add_password_health_report_applications( &mut self, ) -> &mut Expectation
Create an Expectation for mocking the add_password_health_report_applications method
Sourcepub fn expect_drop_password_health_report_application(
&mut self,
) -> &mut Expectation
pub fn expect_drop_password_health_report_application( &mut self, ) -> &mut Expectation
Create an Expectation for mocking the drop_password_health_report_application method
Sourcepub fn expect_get_member_access_report(&mut self) -> &mut Expectation
pub fn expect_get_member_access_report(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_member_access_report method
Sourcepub fn expect_get_member_cipher_details(&mut self) -> &mut Expectation
pub fn expect_get_member_cipher_details(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_member_cipher_details method
Sourcepub fn expect_get_password_health_report_applications(
&mut self,
) -> &mut Expectation
pub fn expect_get_password_health_report_applications( &mut self, ) -> &mut Expectation
Create an Expectation for mocking the get_password_health_report_applications method